==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/rt/rs/security/jose-parent/jose/src/test/java/org/apache/cxf/rs/security/jose/jwa/AbstractJwaTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.jose.jwa;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.security.Provider;
import java.security.Security;

import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;

public class AbstractJwaTest {

    @BeforeClass
    public static void installBouncyCastleProvider() throws Exception {
        final String bcClassName = "org.bouncycastle.jce.provider.BouncyCastleProvider";
        if (Security.getProvider(bcClassName) == null) {
            Security.addProvider((Provider) Class.forName(bcClassName).newInstance());
        }
    }

    @AfterClass
    public static void removeBouncyCastleProvider() {
        Security.removeProvider("org.bouncycastle.jce.provider.BouncyCastleProvider");
    }

    protected String loadResource(String resource) {
        StringBuilder input = new StringBuilder();
        InputStream stream = AbstractDecryptTest.class.getResourceAsStream(resource);
        Assert.assertNotNull("Resource " + resource + " could not be loaded", stream);
        new BufferedReader(new InputStreamReader(stream)).lines().forEach(line -> input.append(line));
        return input.toString();
    }

}

==> apache-cxf-3.6.1-src.tar.gz: apache-cxf-3.6.1-src/rt/rs/security/jose-parent/jose/src/test/java/org/apache/cxf/rs/security/jose/jwa/AbstractJwaTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.jose.jwa;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.security.Provider;
import java.security.Security;

import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;

public class AbstractJwaTest {

    @BeforeClass
    public static void installBouncyCastleProvider() throws Exception {
        final String bcClassName = "org.bouncycastle.jce.provider.BouncyCastleProvider";
        if (Security.getProvider(bcClassName) == null) {
            Security.addProvider((Provider) Class.forName(bcClassName).getDeclaredConstructor().newInstance());
        }
    }

    @AfterClass
    public static void removeBouncyCastleProvider() {
        Security.removeProvider("org.bouncycastle.jce.provider.BouncyCastleProvider");
    }

    protected String loadResource(String resource) {
        StringBuilder input = new StringBuilder();
        InputStream stream = AbstractDecryptTest.class.getResourceAsStream(resource);
        Assert.assertNotNull("Resource " + resource + " could not be loaded", stream);
        new BufferedReader(new InputStreamReader(stream)).lines().forEach(line -> input.append(line));
        return input.toString();
    }

}
